summaryrefslogtreecommitdiff
path: root/user/clang/ppc-interp.patch
blob: fae58aa3da14652916b018497f7ea1ce1775e299 (plain) (blame)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
PPC32 doesn't support some of the clang-repl due to R_PPC_REL24 not being
implemented in RuntimeDyld.

--- clang-14.0.6.src/test/Interpreter/execute.cpp.old	2022-06-22 16:46:24.000000000 +0000
+++ clang-14.0.6.src/test/Interpreter/execute.cpp	2022-12-05 01:04:26.517960246 +0000
@@ -1,4 +1,4 @@
-// UNSUPPORTED: system-aix
+// UNSUPPORTED: system-aix, powerpc-
 
 // clang-format off
 // RUN: clang-repl "int i = 10;" 'extern "C" int printf(const char*,...);' \
--- clang/unittests/Interpreter/InterpreterTest.cpp.old	2024-10-10 18:11:05.390017076 +0000
+++ clang/unittests/Interpreter/InterpreterTest.cpp	2024-10-10 22:34:07.176019197 +0000
@@ -30,7 +30,7 @@
 
 using namespace clang;
 
-#if defined(_AIX)
+#if defined(_AIX) || (!defined(__powerpc64__) && defined(__powerpc__))
 #define CLANG_INTERPRETER_NO_SUPPORT_EXEC
 #endif
 
--- clang/unittests/Interpreter/ExceptionTests/InterpreterExceptionTest.cpp.old	2024-06-15 17:21:32.000000000 +0000
+++ clang/unittests/Interpreter/ExceptionTests/InterpreterExceptionTest.cpp	2024-10-10 22:36:53.358466534 +0000
@@ -113,8 +113,8 @@
   if (Triple.isOSAIX())
     GTEST_SKIP();
 
-  // FIXME: ARM fails due to `Not implemented relocation type!`
-  if (Triple.isARM())
+  // FIXME: ARM and PPC32 fail due to `Not implemented relocation type!`
+  if (Triple.isARM() || Triple.isPPC32())
     GTEST_SKIP();
 
   // FIXME: libunwind on darwin is broken, see PR49692.